from typing import Optional
import requests
from . import exceptions, images, models, utils

class Client:
    """Client class는 thecampy의 메인 class입니다. 
    
    Client 인스턴스를 사용해 The Camp의 인터넷 편지 서비스에 접근할 수 있습니다.
    """
    upload_url_api_key = 'xIerQL8gDg4qKd5sbVjAr7rgzf2FtJ6C4OKgTv25'
    upload_api_key = 'b3JedGhtQo5RFOR2pBpN6amkfAMJTZUY7tosboGt'

    def __init__(self, email, password):
        """Client 인스턴스를 시작합니다.

        :param email: The Camp 웹사이트 계정의 email
        :type email: str
        :param password: The Camp 웹사이트 계정의 비밀번호
        :type password: str
        :return: 로그인 후 Cookie의 iuid와 token 값을 dictionary로 반환합니다.
        :rtype: dict
        """
        form = {
            "state": 'email-login',
            "autoLoginYn": 'N',
            "userId": email,
            "userPwd": password,
        }

        r = requests.post(
            url= utils.request_url('login/loginA.do'),
            json = True,
            data = form,
            headers = {
            'Content-Type': 'application/x-www-form-urlencoded'
            },
        )
        
        if (r.status_code != requests.codes.ok):
            raise exceptions.ThecampyReqError('HTTP 에러: {}'.format(r.status_code))

        self.cookie = models.Cookie(r)

        if (self.cookie.iuid == False or self.cookie.token == False):
            raise exceptions.ThecampyException('알 수 없는 에러 {}'.format(r.json()))
        
    def _enforce_login(self):
        if not hasattr(self, 'cookie'):
            raise exceptions.ThecampyValueError("로그인이 필요합니다.")

    def add_soldier(self, soldier):
        """The camp의 보고싶은 군인에 주어진 훈련병을 추가합니다.

        :param soldier: 훈련병의 Soldier model
        :type soldier: models.Soldier
        """
        self._enforce_login()
        form = {
            "missSoldierClassCdNm": soldier.identity, #성분 반환 (예비군인/훈련병)
            "grpCdNm": '육군',
            "missSoldierClassCd": soldier.identity_code,
            "grpCd": '0000010001',#육군
            "name": soldier.name,
            "birth" : soldier.bday,
            "enterDate" : soldier.enlist_date,
        }

        r = requests.post(
            url = utils.request_url('missSoldier/insertDirectMissSoldierA.do'),
            json = True,
            headers = {
                'Content-Type': 'application/x-www-form-urlencoded',
                'Cookie' : "{}; {}".format(self.cookie.iuid, self.cookie.token)
            },
            data = form
        )
        
        if (r.status_code != requests.codes.ok):
            raise exceptions.ThecampyReqError('HTTP 에러: {}'.format(r.status_code))

        ok_resultCd = ['0000', 'E001']

        if (r.json()['resultCd'] not in ok_resultCd):
            raise exceptions.ThecampyException("알 수 없는 에러: resultCd: {}".format((r.json()['resultCd'])))

    def get_soldier(self, soldier):
        """주어진 훈련병의 고유 id(code)를 class`models.Soldier`에 추가하고, code를 반환합니다.

        :param soldier: 훈련병의 Soldier model
        :type soldier: models.Soldier
        :return: 훈련병의 고유 code
        :rtype: str
        """
        self._enforce_login()
        form = {
            "name" : soldier.name,
            "birth" : soldier.bday,
            "enterDate" : soldier.enlist_date,
            "trainUnitCd": soldier.unit_code,
            "grpCd": '0000010001'
        }
        
        r = requests.post(
            url = utils.request_url('main/cafeCreateCheckA.do'),
            json = True,
            headers = {
                'Content-Type': 'application/x-www-form-urlencoded',
                'Cookie' : "{}; {}".format(self.cookie.iuid, self.cookie.token)
            },
            data = form
        )
        
        if (r.status_code != requests.codes.ok):
            raise exceptions.ThecampyReqError('HTTP 에러: {}'.format(r.status_code))
        
        if not r.json():
            raise exceptions.ThecampyReqError('응답값이 없습니다.')
        
        if r.status_code == 200 and r.json()["resultCd"] != '9999':
            raise exceptions.ThecampyException('알 수 없는 오류: {}'.format(r.json()))

        if len(r.json()['listResult']) == 0:
             raise exceptions.ThecampyValueError("해당하는 훈련병을 찾을 수 없습니다.")

        self.soldier_code = r.json()['listResult'][0]['traineeMgrSeq']
        
        soldier.add_soldier_code(self.soldier_code)

        return self.soldier_code

    def send_message(self, soldier: models.Soldier, message: models.Message,
                     image: Optional[images.ThecampyImage] = None):
        """주어진 Message를 주어진 Soldier에게 the camp 인터넷 편지로 발송합니다. Image가 주어졌다면, 사진도 함께 전송합니다.

        :param soldier: 훈련병의 Soldier 모델
        :type soldier: models.Soldier
        :param message: 보내려는 편지의 Message 모델
        :type message: models.Message
        :param image: 보내려는 사진의 Image 모델, 기본값은 None.
        :type image: Optional[images.ThecampyImage], optional
        """
        self._enforce_login()
        if soldier.identity != '예비군인/훈련병':
            message.is_sent = False
            raise exceptions.ThecampyValueError('예비군인/훈련병에게만 편지를 보낼 수 있습니다.')

        if not soldier.soldier_code:
            message.is_sent = False
            raise exceptions.ThecampyValueError('훈련병 식별코드를 받지 못하였습니다.')

        form = {
            'traineeMgrSeq': soldier.soldier_code,
            'sympathyLetterContent': message.content,
            'sympathyLetterSubject': message.title,
            'boardDiv': 'sympathyLetter',
            'tempSaveYn': 'N',
        }

        if image:
            upload_response = self._upload_image(image)
            form['sympathyLetterEditorFileGroupSeq'] = upload_response.letter_file_group_mgr_seq
            form['fileGroupMgrSeq'] = upload_response.file_group_mgr_seq
            form['fileMgrSeq'] = upload_response.file_mgr_seq

        r = requests.post(
            url=utils.request_url('consolLetter/insertConsolLetterA.do?'),
            json=True,
            headers={
                'Content-Type': 'application/x-www-form-urlencoded',
                'Cookie': "{}; {}".format(self.cookie.iuid, self.cookie.token)
            },
            data=form
        )

        if r.status_code == 200 and r.json()["resultCd"] == '9019':
            message.is_sent = False
            raise exceptions.ThecampyException("9019")
        elif r.json()["resultCd"] != '0000':
            message.is_sent = False
            raise exceptions.ThecampyException("알 수 없는 오류: resultCd={}".format(r.json()["resultCd"]))
        
        if (not r.json()):
            message.is_sent = False
            raise exceptions.ThecampyReqError('응답값이 없습니다.')

        message.is_sent = True

    def _get_upload_url(self, image: images.ThecampyImage) -> str:
        r = requests.post(
            url='https://private-api.thecamp.or.kr/upload/TC-GetUploadURL?s=prd',
            json=[{
                "path": image.path,
                "t": 100,
                "ct": image.ct,
            }],
            headers={
                'x-api-key': self.upload_url_api_key,
            },
        )
        response_data: list = r.json()
        if not response_data:
            raise exceptions.ThecampyReqError('응답값이 없습니다.')
        if not (response_data[0] or response_data[0].get('url')):
            raise exceptions.ThecampyReqError('응답값이 올바르지 않습니다.')
        upload_url = response_data[0]['url']
        return upload_url

    def _upload_cdn(self, image: images.ThecampyImage):

        upload_url = self._get_upload_url(image)

        with image as f:
            r = requests.put(
                url=upload_url,
                data=f,
                headers={
                    'x-api-key': self.upload_api_key,
                }
            )
        if r.status_code != 200:
            raise exceptions.ThecampyReqError('이미지 업로드에 실패하였습니다.')

    def _upload_image(self, image: images.ThecampyImage) -> models.FileUploadResponse:
        self._upload_cdn(image)
        form = {
            'boardDiv': 'sympathyLetter',
            'savedFileNm': image.saved_file_name,
            'filePath': image.file_path,
            'oriFileNm': 'upload',
            'extNm': image.metadata.type.lower(),
            'fileSize': str(image.metadata.file_size),
            'imgWSize': str(image.metadata.width),
            'imgHSize': str(image.metadata.height),
            'fileType': 'image',
        }

        r = requests.post(
            url=utils.request_url('commonFileUploadCdn.do'),
            headers={
                'Content-Type': 'application/x-www-form-urlencoded',
                'Cookie': "{}; {}".format(self.cookie.iuid, self.cookie.token)
            },
            data=form,
        )
        response_data: dict = r.json()
        if not response_data:
            raise exceptions.ThecampyReqError('응답값이 없습니다.')
        result_code = response_data.get('resultCd')

        if r.status_code == 200 and result_code == '9019':
            raise exceptions.ThecampyException("9019")
        elif result_code != '0000':
            raise exceptions.ThecampyException(f"알 수 없는 오류: resultCd={result_code}")

        try:
            return models.FileUploadResponse(
                file_group_mgr_seq=response_data['fileGroupMgrSeq'],
                file_mgr_seq=response_data['fileMgrSeq'],
                letter_file_group_mgr_seq=response_data['fileList'][0]['sympathyLetterFileGroupMgrSeq'],
            )
        except KeyError:
            raise exceptions.ThecampyReqError('응답값이 올바르지 않습니다.') from None


from typing import NamedTuple
from . import exceptions

"""부대와 해당 부대 코드의 dictionary입니다.

Soldier class를 initialize 할때의 unit parameter는 아래의 dictionary의 해당 부대 key값과 정확히 일치해야합니다.
"""

unit_codes = {
    '1사단' : '20121290100',
    '2사단' : '20121490100',
    '3사단' : '20121590100',
    '5사단' : '20121690200',
    '6사단' : '20121590200',
    '7사단' : '20121390100',
    '9사단' : '20121290200',
    '11사단' : '20121790300',
    '12사단' : '20121490200',
    '15사단' : '20121390200',
    '17사단' : '20121190100',
    '20사단' : '20121790400',
    '21사단' : '20121490300',
    '22사단' : '20121890100',
    '23사단' : '20121890200',
    '25사단' : '20121290300',
    '27사단' : '20121390300',
    '28사단' : '20121690100',
    '30사단' : '20121290400',
    '31사단' : '20220280100',
    '32사단' : '20220280200',
    '35사단' : '20220280300',
    '36사단' : '20120180100',
    '37사단' : '20220280400',
    '39사단' : '20220280500',
    '50사단' : '20220280600',
    '51사단' : '20121190200',
    '53사단' : '20220280700',
    '55사단' : '20120180200',
    '육군훈련소' : '20020191700',
    '육군훈련소(23연대)' : '20020191800', # 육군훈련소 연대별 구분은 사라진 것 같습니다.
    '육군훈련소(25연대)' : '20020191900',
    '육군훈련소(26연대)' : '20020192000',
    '육군훈련소(27연대)' : '20020192100',
    '육군훈련소(28연대)' : '20020192200',
    '육군훈련소(29연대)' : '20020192300',
    '육군훈련소(30연대)' : '20020192400',
}

class Cookie:
    """the camp의 로그인 request에서 iuid와 token을 저장하는 모델입니다.
    """
    def __init__(self, r):
        """Cookie 모델을 만듭니다.

        :param r: requests.Response object
        :type r: requests.Response
        """
        try:
            cookie_header = r.headers['set-cookie']
            num_iuid = cookie_header.find('iuid=')
            num_token = cookie_header.find('Token=')
            self.iuid = cookie_header[num_iuid:num_iuid + 12]
            self.token = cookie_header[num_token:num_token + 36]
        except KeyError:
            self.iuid = None
            self.token = None

    def iuid(self):
        return self.iuid

    def token(self):
        return self.token


class Soldier:
    """훈련병의 정보를 저장하는 모델입니다.
    """
    def __init__(self, name, bday, enlist_date, unit):
        """Soldier 모델을 만듭니다.

        :param name: 훈련병의 이름
        :type name: str
        :param bday: 훈련병의 생년월일 ex) 19990812
        :type bday: int
        :param enlist_date: 훈련병의 입대일 ex)20200818
        :type enlist_date: int
        :param unit: 훈련병의 입대부대명(unit_codes 참고)
        :type unit: str
        """
        if unit not in unit_codes:
            raise exceptions.ThecampyValueError('해당 사단/육군훈련소 연대가 존재하지 않습니다.')

        unit_code = unit_codes[unit]

        self.name = name
        self.bday = bday
        self.enlist_date = enlist_date
        self.identity = "예비군인/훈련병"
        self.identity_code = '0000490001'
        self.army = '0000010001' #육군 코드
        self.unit = unit
        self.unit_code = unit_code

    def add_soldier_code(self, code):
        self.soldier_code = code

class Message:
    """훈련병에게 보낼 편지의 모델입니다.
    """
    def __init__(self, title, content):
        """Message 모델을 시작합니다.

        :param title: 편지의 제목입니다.
        :type title: str
        :param content: 편지의 내용입니다. (편지 내용은 1500자를 넘을 수 없습니다.)
        :type content: str
        """
        if len(content) > 1500:
            raise exceptions.ThecampyValueError("편지 내용이 1500자를 넘습니다.")
        self.title = title
        self.content = content

    @property
    def is_sent(self):
        return self._is_sent
    
    @is_sent.setter
    def is_sent(self, is_sent):
        if type(is_sent) is type(True):
            self._is_sent = is_sent
        else:
            raise exceptions.ThecampyValueError('is_sent must be bool')
    
    @is_sent.deleter
    def is_sent(self):
        del self._is_sent


class FileUploadResponse(NamedTuple):
    file_group_mgr_seq: str
    file_mgr_seq: str
    letter_file_group_mgr_seq: str


"""
written based on this repo: https://github.com/scardine/image_size
"""
import collections
import json
import os
import struct
import typing

FILE_UNKNOWN = "Sorry, don't know how to get size for this file."


class UnknownImageFormat(Exception):
    pass


types = collections.OrderedDict()
BMP = types['BMP'] = 'BMP'
GIF = types['GIF'] = 'GIF'
ICO = types['ICO'] = 'ICO'
JPEG = types['JPEG'] = 'JPEG'
PNG = types['PNG'] = 'PNG'
TIFF = types['TIFF'] = 'TIFF'


class ImageMetadata(typing.NamedTuple):
    type: str
    file_size: int
    width: int
    height: int

    def to_str_row(self):
        return ("%d\t%d\t%d\t%s" % (
            self.width,
            self.height,
            self.file_size,
            self.type,
        ))

    def to_str_row_verbose(self):
        return ("%d\t%d\t%d\t%s\t##%s" % (
            self.width,
            self.height,
            self.file_size,
            self.type,
            self))

    def to_str_json(self, indent=None):
        return json.dumps(self._asdict(), indent=indent)


def get_image_metadata(file_path: str) -> ImageMetadata:
    """
    Return an `ImageMetadata` object for a given img file content - no external
    dependencies except the os and struct builtin modules

    :param file_path: path to an image file
    :return: ImageMetadata: (type, file_size, width, height)
    """

    size = os.path.getsize(file_path)

    # be explicit with open arguments - we need binary mode
    with open(file_path, "rb") as f:
        return get_image_metadata_from_bytesio(f, size)


def get_image_metadata_from_bytesio(f: typing.BinaryIO, size: int) -> ImageMetadata:
    """
    Return an `ImageMetadata` object for a given img file content - no external
    dependencies except the os and struct builtin modules

    :param f: io object support read & seek
    :param size: size of buffer in byte
    :return: ImageMetadata: (type, file_size, width, height)
    """

    height = -1
    width = -1
    data = f.read(26)
    msg = " raised while trying to decode as JPEG."

    if (size >= 10) and data[:6] in (b'GIF87a', b'GIF89a'):
        # GIFs
        img_type = GIF
        w, h = struct.unpack("<HH", data[6:10])
        width = int(w)
        height = int(h)
    elif ((size >= 24) and data.startswith(b'\211PNG\r\n\032\n')
          and (data[12:16] == b'IHDR')):
        # PNGs
        img_type = PNG
        w, h = struct.unpack(">LL", data[16:24])
        width = int(w)
        height = int(h)
    elif (size >= 16) and data.startswith(b'\211PNG\r\n\032\n'):
        # older PNGs
        img_type = PNG
        w, h = struct.unpack(">LL", data[8:16])
        width = int(w)
        height = int(h)
    elif (size >= 2) and data.startswith(b'\377\330'):
        # JPEG
        img_type = JPEG
        f.seek(0)
        f.read(2)
        b = f.read(1)
        try:
            w = h = -1
            while b and ord(b) != 0xDA:
                while ord(b) != 0xFF:
                    b = f.read(1)
                while ord(b) == 0xFF:
                    b = f.read(1)
                if 0xC0 <= ord(b) <= 0xC3:
                    f.read(3)
                    h, w = struct.unpack(">HH", f.read(4))
                    break
                else:
                    f.read(
                        int(struct.unpack(">H", f.read(2))[0]) - 2)
                b = f.read(1)
            width = int(w)
            height = int(h)
        except struct.error:
            raise UnknownImageFormat("StructError" + msg)
        except ValueError:
            raise UnknownImageFormat("ValueError" + msg)
        except Exception as e:
            raise UnknownImageFormat(e.__class__.__name__ + msg)
    elif (size >= 26) and data.startswith(b'BM'):
        # BMP
        img_type = 'BMP'
        header_size = struct.unpack("<I", data[14:18])[0]
        if header_size == 12:
            w, h = struct.unpack("<HH", data[18:22])
            width = int(w)
            height = int(h)
        elif header_size >= 40:
            w, h = struct.unpack("<ii", data[18:26])
            width = int(w)
            # as h is negative when stored upside down
            height = abs(int(h))
        else:
            raise UnknownImageFormat(f"Unknown DIB header size:{header_size}")
    elif (size >= 8) and data[:4] in (b"II\052\000", b"MM\000\052"):
        # Standard TIFF, big- or little-endian
        # BigTIFF and other different but TIFF-like formats are not
        # supported currently
        img_type = TIFF
        byte_order = data[:2]
        bo_char = ">" if byte_order == "MM" else "<"
        # maps TIFF type id to size (in bytes)
        # and python format char for struct
        tiff_types = {
            1: (1, bo_char + "B"),  # BYTE
            2: (1, bo_char + "c"),  # ASCII
            3: (2, bo_char + "H"),  # SHORT
            4: (4, bo_char + "L"),  # LONG
            5: (8, bo_char + "LL"),  # RATIONAL
            6: (1, bo_char + "b"),  # SBYTE
            7: (1, bo_char + "c"),  # UNDEFINED
            8: (2, bo_char + "h"),  # SSHORT
            9: (4, bo_char + "l"),  # SLONG
            10: (8, bo_char + "ll"),  # SRATIONAL
            11: (4, bo_char + "f"),  # FLOAT
            12: (8, bo_char + "d")  # DOUBLE
        }
        ifd_offset = struct.unpack(bo_char + "L", data[4:8])[0]
        try:
            count_size = 2
            f.seek(ifd_offset)
            ec = f.read(count_size)
            ifd_entry_count = struct.unpack(bo_char + "H", ec)[0]
            # 2 bytes: TagId + 2 bytes: type + 4 bytes: count of values + 4
            # bytes: value offset
            ifd_entry_size = 12
            for i in range(ifd_entry_count):
                entry_offset = ifd_offset + count_size + i * ifd_entry_size
                f.seek(entry_offset)
                tag = f.read(2)
                tag = struct.unpack(bo_char + "H", tag)[0]
                if tag == 256 or tag == 257:
                    # if type indicates that value fits into 4 bytes, value
                    # offset is not an offset but value itself
                    _type = f.read(2)
                    _type = struct.unpack(bo_char + "H", _type)[0]
                    if _type not in tiff_types:
                        raise UnknownImageFormat(
                            "Unknown TIFF field type:" +
                            str(_type))
                    type_size = tiff_types[_type][0]
                    type_char = tiff_types[_type][1]
                    f.seek(entry_offset + 8)
                    value = f.read(type_size)
                    value = int(struct.unpack(type_char, value)[0])
                    if tag == 256:
                        width = value
                    else:
                        height = value
                if width > -1 and height > -1:
                    break
        except Exception as e:
            raise UnknownImageFormat(str(e))
    elif size >= 2:
        # see http://en.wikipedia.org/wiki/ICO_(file_format)
        img_type = 'ICO'
        f.seek(0)
        reserved = f.read(2)
        if 0 != struct.unpack("<H", reserved)[0]:
            raise UnknownImageFormat(FILE_UNKNOWN)
        _format = f.read(2)
        assert 1 == struct.unpack("<H", _format)[0]
        num = f.read(2)
        num = struct.unpack("<H", num)[0]
        if num > 1:
            import warnings
            warnings.warn("ICO File contains more than one image")
        # http://msdn.microsoft.com/en-us/library/ms997538.aspx
        w = f.read(1)
        h = f.read(1)
        width = ord(w)
        height = ord(h)
    else:
        raise UnknownImageFormat(FILE_UNKNOWN)

    return ImageMetadata(type=img_type,
                         file_size=size,
                         width=width,
                         height=height)



import io
from typing import BinaryIO, Union

from . import exceptions, image_utils, utils


class ThecampyImage:
    metadata: image_utils.ImageMetadata
    saved_file_name: str
    file_path: str
    path: str
    ct: str
    fp: BinaryIO
    is_uploaded: bool

    def __init__(self, image_file: Union[str, bytes, BinaryIO], image_size=0):
        """
        :param image_file: 파일 경로, bytes, file like object, ThecampyImage 타입을 지원합니다.
        :param image_size: (optional) image_file 이 file like object 인 경우 image_size 를 지정합니다.
        """
        self.is_uploaded = False
        self._local_file_path = ''
        try:
            if isinstance(image_file, str):
                self._local_file_path = image_file
                self.metadata = image_utils.get_image_metadata(image_file)
            elif isinstance(image_file, bytes):
                image_size = len(image_file)
                with io.BytesIO(image_file) as buffer:
                    self.metadata = image_utils.get_image_metadata_from_bytesio(buffer, image_size)
                self.fp = io.BytesIO(image_file)
            elif isinstance(image_file, BinaryIO):
                if not image_size:
                    image_bytes = image_file.read()
                    image_size = len(image_bytes)
                self.metadata = image_utils.get_image_metadata_from_bytesio(image_file, image_size)
                image_file.seek(0)
                self.fp = image_file
            else:
                raise TypeError('`image_file` 는 file path str, image_file bytes, binary file like object 만 지원합니다.')
        except image_utils.UnknownImageFormat:
            raise exceptions.ThecampyValueError('지원되지 않는 이미지 포맷 이거나 잘못된 이미지 파일 입니다.') from None

        self.raise_invalid_image()

        now = utils.get_kr_now()
        date_str = now.strftime('%Y%m%d')
        name = f'{now.strftime("%Y%m%d%H%M%S%f")[:17]}_ge1'
        ext = self.metadata.type.lower()
        file_dir = f'/images/upload/{date_str}/1234/'
        path = f'{file_dir}{name}.{ext}'
        self.saved_file_name = name
        self.file_path = file_dir
        self.path = path
        self.ct = f'image_file/{ext}'

    def raise_invalid_image(self):
        allow_image_format = {'jpeg', 'png', 'bmp', 'jpg', 'gif'}
        if self.metadata.type.lower() not in allow_image_format:
            raise exceptions.ThecampyValueError('허용하지 않는 이미지 포맷입니다.')
        if 10_485_760 < self.metadata.file_size:
            raise exceptions.ThecampyValueError('10MB 를 초과하는 이미지를 업로드 할 수 없습니다.')

    def close(self):
        self.fp.close()

    def __enter__(self):
        if self.is_uploaded:
            raise exceptions.ThecampyReqError('이미 업로드 한 이미지 입니다.')
        if self._local_file_path:
            self.fp = open(self._local_file_path, 'rb')
        return self.fp

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.is_uploaded = True
        self.close()



from datetime import datetime, timedelta, timezone
seoul_timezone = timezone(timedelta(hours=9), 'Asia/Seoul')


def request_url(resource):
    baseUrl = 'https://www.thecamp.or.kr'
    r = "{}/{}".format(baseUrl, resource)
    return r


def get_kr_now():
    return datetime.now(tz=timezone.utc).astimezone(tz=seoul_timezone)



from . import image_utils, utils
from .client import Client
from .exceptions import ThecampyException, ThecampyReqError, ThecampyValueError
from .images import ThecampyImage
from .models import Cookie, Message, Soldier

__all__ = ['utils', 'image_utils', 'Client', 'Cookie', 'Soldier', 'Message', 'ThecampyException', 'ThecampyValueError',
           'ThecampyReqError', 'ThecampyImage']



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="thecampy", # Replace with your own username
    version="3.0.2",
    author="lewisleedev",
    author_email="lewislee@lewislee.net",
    description="더 캠프 인터넷편지 비공식 라이브러리",
    url="https://github.com/lewisleedev/thecampy",
    packages=setuptools.find_packages(),
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "requests"
    ],
    python_requires='>=3.6',
)
